==> liveshot-1.0.3.tgz: package/src/renderer/CardRenderer.js <==
var inherits = require('inherits');
var targets = require('../target/targets');

var Renderer = require('./Renderer');
var ShotRenderer = require('./ShotRenderer');
var TriangleRenderer = require('./TriangleRenderer');
var CardBuilder = require('../protocol/CardBuilder');

function CardRenderer() {
    Renderer.prototype.constructor.apply(this);

    this.initialize();
}

module.exports = CardRenderer;
inherits(CardRenderer, Renderer);

// --- External API ---
CardRenderer.prototype.setStyle = function (style) {
    for (var key in this.style) {
        if (style.hasOwnProperty(key))
            this.style[key] = style[key];
    }

    this.targetRenderer.setStyle(style);
    this.shotRenderer.setStyle(style);
    this.triangleRenderer.setStyle(style);

    return this;
};

CardRenderer.prototype.setCard = function (card, valid) {
    if (!valid) {
        card = CardBuilder.sanitizeCard(card);
    }

    this.card = card;

    this.setTarget(this.card.config.targetID);
    this.setGaugeSize(this.card.config.gaugeSize);
    this.setShots(this.card.result.shots);

    return this;
};

// --- Internal API ---
CardRenderer.prototype.initialize = function () {
    this.style = {
        backColor:'rgb(255, 255, 255)',
        frontColor:'rgb(0, 0, 0)'
    };

    this.shotRenderer = new ShotRenderer();
    this.triangleRenderer = new TriangleRenderer();

    this.setCard(CardBuilder.createBlankCard());
};

CardRenderer.prototype.draw = function () {
    this.updateScale();

    this.drawTarget();
    this.drawShots();
    this.drawTriangle();
};

CardRenderer.prototype.updateScale = function () {
    var prevScale = this.scale;
    this.scale = this.scaler.getScale();

    this.targetRenderer.setScale(this.scale);
    this.shotRenderer.setScale(this.scale);

    if (prevScale && prevScale > this.scale) {
        this.clearTarget();
    }
};

CardRenderer.prototype.clearTarget = function () {
    var targetRect = this.getTargetRect();

    this.context.clearRect(targetRect.x, targetRect.y, targetRect.width, targetRect.height);
};

CardRenderer.prototype.drawTarget = function () {
    this.targetRenderer.render();
};

CardRenderer.prototype.drawShots = function () {
    this.shotRenderer.render();
};

CardRenderer.prototype.drawTriangle = function () {
    if (!this.card.result.marking) {
        this.triangleRenderer.render();
    }
};

CardRenderer.prototype.setPosition = function (x, y) {
    var res = Renderer.prototype.setPosition.apply(this, [x, y]);

    this.updateTargetRect();

    return res;
};

CardRenderer.prototype.setSize = function (width, height) {
    var res = Renderer.prototype.setSize.apply(this, [width, height]);

    this.updateTargetRect();

    return res;
};

CardRenderer.prototype.setRect = function (rect) {
    var res = Renderer.prototype.setRect.apply(this, [rect]);

    this.updateTargetRect();

    return res;
};

CardRenderer.prototype.updateTargetRect = function () {
    var targetRect = this.getTargetRect();

    this.targetRenderer.setRect(targetRect);
    this.shotRenderer.setRect(targetRect);
    this.triangleRenderer.setRect(targetRect);
};

CardRenderer.prototype.setContext = function (context) {
    var res = Renderer.prototype.setContext.apply(this, [context]);

    this.targetRenderer.setContext(this.context);
    this.shotRenderer.setContext(this.context);
    this.triangleRenderer.setContext(this.context);

    return this;
};

CardRenderer.prototype.setTarget = function (targetID) {
    if (this.targetID == targetID) {
        return;
    }

    this.targetID = targetID;

    this.scaler = targets.getScaler(this.targetID);

    var style = this.targetRenderer ? this.targetRenderer.style : {};
    this.targetRenderer = targets.getRenderer(this.targetID);
    this.targetRenderer.setStyle(style);

    this.setRect(this.rect);
    this.setContext(this.context);
};

CardRenderer.prototype.setShots = function (shots) {
    if (this.shots == shots) {
        return;
    }

    this.shots = shots;

    this.scaler.setShots(shots);
    this.shotRenderer.setShots(shots);
};

CardRenderer.prototype.setGaugeSize = function (gaugeSize) {
    if (this.gaugeSize == gaugeSize) {
        return;
    }

    this.gaugeSize = gaugeSize;
    this.shotRenderer.setStyle({gaugeSize:gaugeSize});
};

// --- Helper methods ---
CardRenderer.prototype.getTargetRect = function () {
    return CardRenderer.getTargetRect(this.rect);
};

CardRenderer.getTargetRect = function (rect) {
    return rect;
};

==> liveshot-1.0.17.tgz: package/src/renderer/CardRenderer.js <==
var inherits = require('inherits');
var targets = require('../target/targets');

var Renderer = require('./Renderer');
var TriangleRenderer = require('./TriangleRenderer');
var CardBuilder = require('../protocol/CardBuilder');

function CardRenderer() {
    Renderer.prototype.constructor.apply(this);

    this.initialize();
}

module.exports = CardRenderer;
inherits(CardRenderer, Renderer);

// --- External API ---
CardRenderer.prototype.setStyle = function (style) {
    for (var key in this.style) {
        if (style.hasOwnProperty(key))
            this.style[key] = style[key];
    }

    this.targetRenderer.setStyle(style);
    this.shotRenderer.setStyle(style);
    this.triangleRenderer.setStyle(style);

    return this;
};

CardRenderer.prototype.setCard = function (card, valid) {
    if (!valid) {
        card = CardBuilder.sanitizeCard(card);
    }

    this.card = card;

    this.setTarget(this.card.config.targetID);
    this.setGaugeSize(this.card.config.gaugeSize);
    this.setShots(this.card.result.shots);

    return this;
};

// --- Internal API ---
CardRenderer.prototype.initialize = function () {
    this.style = {
        backColor:'rgb(255, 255, 255)',
        frontColor:'rgb(0, 0, 0)'
    };

    this.triangleRenderer = new TriangleRenderer();

    this.setCard(CardBuilder.createBlankCard());
};

CardRenderer.prototype.draw = function () {
    this.updateScale();

    this.drawTarget();
    this.drawShots();
    this.drawTriangle();
};

CardRenderer.prototype.updateScale = function () {
    var prevScale = this.scale;
    this.scale = this.scaler.getScale();

    this.targetRenderer.setScale(this.scale);
    this.shotRenderer.setScale(this.scale);

    if (prevScale && prevScale > this.scale) {
        this.clearTarget();
    }
};

CardRenderer.prototype.clearTarget = function () {
    var targetRect = this.getTargetRect();

    this.context.clearRect(targetRect.x, targetRect.y, targetRect.width, targetRect.height);
};

CardRenderer.prototype.drawTarget = function () {
    this.targetRenderer.render();
};

CardRenderer.prototype.drawShots = function () {
    this.shotRenderer.render();
};

CardRenderer.prototype.drawTriangle = function () {
    if (!this.card.result.marking) {
        this.triangleRenderer.render();
    }
};

CardRenderer.prototype.setPosition = function (x, y) {
    var res = Renderer.prototype.setPosition.apply(this, [x, y]);

    this.updateTargetRect();

    return res;
};

CardRenderer.prototype.setSize = function (width, height) {
    var res = Renderer.prototype.setSize.apply(this, [width, height]);

    this.updateTargetRect();

    return res;
};

CardRenderer.prototype.setRect = function (rect) {
    var res = Renderer.prototype.setRect.apply(this, [rect]);

    this.updateTargetRect();

    return res;
};

CardRenderer.prototype.updateTargetRect = function () {
    var targetRect = this.getTargetRect();

    this.targetRenderer.setRect(targetRect);
    this.shotRenderer.setRect(targetRect);
    this.triangleRenderer.setRect(targetRect);
};

CardRenderer.prototype.setContext = function (context) {
    var res = Renderer.prototype.setContext.apply(this, [context]);

    this.targetRenderer.setContext(this.context);
    this.shotRenderer.setContext(this.context);
    this.triangleRenderer.setContext(this.context);

    return this;
};

CardRenderer.prototype.setTarget = function (targetID) {
    if (this.targetID == targetID) {
        return;
    }

    this.targetID = targetID;

    this.scaler = targets.getScaler(this.targetID);

    var targetStyle = this.targetRenderer ? this.targetRenderer.style : {};
    this.targetRenderer = targets.getTargetRenderer(this.targetID);
    this.targetRenderer.setStyle(targetStyle);

    var shotStyle = this.shotRenderer ? this.shotRenderer.style : {};
    this.shotRenderer = targets.getShotRenderer(this.targetID);
    this.shotRenderer.setStyle(targetStyle);

    this.setRect(this.rect);
    this.setContext(this.context);
};

CardRenderer.prototype.setShots = function (shots) {
    if (this.shots == shots) {
        return;
    }

    this.shots = shots;

    this.scaler.setShots(shots);
    this.shotRenderer.setShots(shots);
};

CardRenderer.prototype.setGaugeSize = function (gaugeSize) {
    if (this.gaugeSize == gaugeSize) {
        return;
    }

    this.gaugeSize = gaugeSize;
    this.shotRenderer.setStyle({gaugeSize:gaugeSize});
};

// --- Helper methods ---
CardRenderer.prototype.getTargetRect = function () {
    return CardRenderer.getTargetRect(this.rect);
};

CardRenderer.getTargetRect = function (rect) {
    return rect;
};
